@@ -232,8 +232,8 @@ sheet_order = [
     "User", "Award", "Lab", "Document", "Protocol", "ExperimentType",
     "Publication", "Organism", "Vendor", "IndividualChicken", "IndividualFly",
     "IndividualHuman", "IndividualMouse", "IndividualPrimate",
-    "IndividualZebrafish", "FileFormat", "Enzyme", "Gene", "BioFeature",
-    "Construct", "TreatmentRnai", "TreatmentAgent", "GenomicRegion",
+    "IndividualZebrafish", "FileFormat", "Enzyme", "GenomicRegion", "Gene",
+    "BioFeature", "Construct", "TreatmentRnai", "TreatmentAgent",
     "Antibody", "Modification", "Image", "Biosource", "BiosampleCellCulture",
     "Biosample", "FileFastq", "FileProcessed", "FileReference",
     "FileCalibration", "FileSet", "FileSetCalibration", "MicroscopeSettingD1",
